@@ -8,8 +8,8 @@ class db(object):
     async def get(self, table, query, projection=None, options=None):
         """ahmad = await db.get('test', {'age', 20})"""
         queue = asyncio.Queue()
-        if projection is None:
-            projection = {}
+        '''if projection is None:
+            projection = {}'''
         if options is None:
             options = {}
 
@@ -24,14 +24,14 @@ class db(object):
         return await queue.get()
 
     async def first(self, table, query, projection=None, options=None):
-        result = await self.get(table, query, projection, options)
+        result = await self.get(table, query, projection, options if options else {'$limit':1})
         if result:
             return result[0]
         else:
             return None
 
     async def last(self, table, query, projection=None, options=None):
-        result = await self.get(table, query, projection, options)
+        result = await self.get(table, query, projection, options if options else {'$limit':1, '$sort':{'$natural':-1}})
         if result:
             return result[-1]
         else:
@@ -68,7 +68,7 @@ class db(object):
             self.nw.send('db', 'set', table, json.dumps(value), json.dumps(value))
         else:
             self.nw.send('db', 'set', table, json.dumps(value))
-        self.nw.when('db.' + table, db_result)
+        self.nw.when('db.' + table + '_id', db_result)
         return await queue.get()
 
     async def aggregate(self, table, query):
@@ -91,10 +91,16 @@ if __name__ == '__main__':
         ahmad = await mydb.get('test', {})
         print(ahmad)
 
-    def connected():
+    async def connected():
+        await asyncio.sleep(10)
         mydb = db(ctrl.nw)
-        mydb.set('test', {'name':'ahmad sadiq', 'age': 43})
+        #id = await mydb.set_wait('test', {'name':'ahmad sadiq', 'age': 43})
+        #print(id)
+        r = await mydb.first('test', {})
+        print(r)
+
 
     ctrl = control()
     ctrl.nw.on_connected = connected
+    ctrl.nw.debug = True
     ctrl.nw.run(myloop())
\ No newline at end of file
