@@ -61,15 +61,16 @@ def split(s):
               if token == '=' or isparam: #  is this one a param?, then add to previous token
                   isparam = not isparam
                   tokens[-1]+= token
+                  print(tokens[-1])
               else:                       # else then a separate token
                 tokens.append(token)
               token = ''                  # reset params
               sep = ''
               tokcount=0
-          elif c!= ' ' and len(token)==0:                  #
+          elif c!= ' ' and len(token)==0: # begin token
               sep = c
               tokcount+=1
-          elif c!= ' ':
+          elif c!= ' ':             # continue token, ignore separators not preceded by spaces
               token += c
       elif c in [' ', '[', '(', '{'] and c==sep:
           tokcount+=1
